package org.iphsoft.simon1.ui;

import android.content.Context;
import android.content.res.TypedArray;
import android.graphics.LinearGradient;
import android.graphics.Shader;
import android.graphics.Typeface;
import android.util.AttributeSet;
import android.widget.TextView;

import com.mojotouch.R;

import org.iphsoft.simon1.AndroidPortAdditions;
import org.iphsoft.simon1.AndroidPortAdditions.GameType;

public class ExtendedTextView extends TextView {

	public ExtendedTextView(Context context, AttributeSet attrs, int defStyle)
	{
		super(context, attrs, defStyle);

		init(context, attrs);
	}

	public ExtendedTextView(Context context, AttributeSet attrs)
	{
		super(context, attrs);

		init(context, attrs);
	}

	public ExtendedTextView(Context context)
	{
		super(context);

		init(context, null);
	}

	protected void init(Context context, AttributeSet attrs)
	{
		if (!isInEditMode())
		{
			// Set font

			String tfName = null;
			if (attrs != null)
			{
				TypedArray a = getContext().obtainStyledAttributes(attrs,
						R.styleable.ExtendedTextView);

				tfName = a.getString(R.styleable.ExtendedTextView_typefaceName);
			}

			if (tfName == null)
			{
				switch (AndroidPortAdditions.GAME_TYPE)
				{
				case SIMON1:
				case SIMON2:
					tfName = "scarecrow.ttf";
					break;
				case T7G:
					tfName = "abaddon.ttf";
					break;
				case FOTAQ:
					tfName = "adventure.ttf";
					break;
				case IHNM:
					tfName = "digitall.ttf";
					break;
				}
			}

			Typeface tf = Typeface.createFromAsset(context.getAssets(), tfName);
			setTypeface(tf);
		}
		
		if (AndroidPortAdditions.GAME_TYPE == GameType.IHNM)
		{
			setText(getText().toString().toUpperCase());
			
			float scale = getResources().getDisplayMetrics().density;
			float shadowRadius = 1.5f * scale;
			setShadowLayer(shadowRadius, 0.0f, 0.0f, 0xff918c4c);
		}
	}
	
	@Override
	public void setText(CharSequence text, BufferType type)
	{
		if (AndroidPortAdditions.GAME_TYPE == GameType.IHNM)
		{
			text = text.toString().toUpperCase();
		}
		
		super.setText(text, type);
	}

	@Override
	protected void onLayout(boolean changed, int left, int top, int right, int bottom)
	{
		super.onLayout(changed, left, top, right, bottom);

		// IHNM - apply text gradient
		if (AndroidPortAdditions.GAME_TYPE == GameType.IHNM)
		{
			if (changed)
			{
				getPaint().setShader(
						new LinearGradient(0, 0, 0, getHeight(),
								Gradients.IHNM_GRADIENT_COLORS, null, Shader.TileMode.CLAMP));
			}
		}
	}

}
