package org.iphsoft.simon1.ui;

import android.content.Context;
import android.graphics.LinearGradient;
import android.graphics.Shader;
import android.graphics.Typeface;
import android.util.AttributeSet;
import android.view.Gravity;

import com.mojotouch.R;

public class FOTAQButton extends MagicTextView {

	public FOTAQButton(Context context)
	{
		super(context);
	}

	public FOTAQButton(Context context, AttributeSet attrs, int defStyle)
	{
		super(context, attrs, defStyle);
	}

	public FOTAQButton(Context context, AttributeSet attrs)
	{
		super(context, attrs);
	}

	@Override
	public void init(AttributeSet attrs)
	{
		super.init(attrs);
		
		if (!isInEditMode())
		{
			// Set font
			Typeface tf = Typeface.createFromAsset(getContext().getAssets(), "adventure.ttf");
			setTypeface(tf);
		}

		// Set text sizes
		float density = getResources().getDisplayMetrics().density;
		setTextSize(getResources().getDimensionPixelSize(R.dimen.button_text_size) / density);

		setTextColor(getResources().getColorStateList(R.drawable.button_text_color));
		
		setGravity(Gravity.CENTER);
		
		// Set padding
		setPadding(0, 0, 0, 2);

		// Set background
		setBackgroundResource(R.drawable.button_selector);
		
	//	updateShadows();

		setLines(1);
		setMaxLines(1);
		
		updateState();
	}
	
	@Override
	protected void drawableStateChanged()
	{
		super.drawableStateChanged();

		updateState();
		invalidate();
	}

	@Override
	protected void onLayout(boolean changed, int left, int top, int right, int bottom)
	{
		super.onLayout(changed, left, top, right, bottom);

		if (changed)
		{
			updateState();
		}
	}
		
	private void updateState()
	{
		// Get the relevant drawable state
		boolean statePressed = false, stateEnabled = false;
		int[] states = getDrawableState();
		for (int state : states)
		{
			if (state == android.R.attr.state_enabled)
				stateEnabled = true;
			else if (state == android.R.attr.state_pressed)
				statePressed = true;
		}

		if (getHeight() >= 0)
		{
			float shadowRadius = 0.0f;
			int color1;
			int color2;
			if (stateEnabled == false)
			{
				color1 = Gradients.FOTAQ_GRADIENT_COLORS_DISABLED[0];
				color2 = Gradients.FOTAQ_GRADIENT_COLORS_DISABLED[1];
			} else if (statePressed)
			{
				shadowRadius = 1.0f;
				color1 = Gradients.FOTAQ_GRADIENT_COLORS_PRESSED[0];
				color2 = Gradients.FOTAQ_GRADIENT_COLORS_PRESSED[1];
			} else
			{
				shadowRadius = 1.0f;
				color1 = Gradients.FOTAQ_GRADIENT_COLORS[0];
				color2 = Gradients.FOTAQ_GRADIENT_COLORS[1];
			}
			
			clearOuterShadows();
			
			// Adjust shadow radious to screen density
			float scale = getResources().getDisplayMetrics().density;
			shadowRadius *= scale;
			
	//		addOuterShadow(shadowRadius, 0.0f, 4.0f, 0xff000000);

			Shader shader = new LinearGradient(0, 0, 0, getHeight(), color1, color2,
					Shader.TileMode.CLAMP);
			// Matrix matrix = new Matrix();
			// matrix.setRotate(90);
			// shader.setLocalMatrix(matrix);
			getPaint().setShader(shader);
		}

	}
}
